#############################################################################
#
# Copyright (c) 2010 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import grok
import martian


class SecurityError(grok.GrokError):
    pass


_require_marker = object()


class CheckRequireGrokker(martian.ClassGrokker):
    """Ensure every grok.View has a grok.require directive"""
    martian.component(grok.View)
    martian.directive(grok.require, default=_require_marker)

    def execute(self, factory, config, require, **kw):
        if require is _require_marker:
            raise SecurityError(
                'megrok.strictrequire requires %r to use the grok.require '
                'directive!' % factory, factory)
        return True


class CheckRequireGrokkerPage(CheckRequireGrokker):
    """Ensure every grok.Page has a grok.require directive"""
    martian.component(grok.Page)


class CheckRequireGrokkerViewlet(CheckRequireGrokker):
    """Ensure every grok.Viewlet has a grok.require directive"""
    martian.component(grok.Viewlet)


class CheckRequireGrokkerForm(CheckRequireGrokker):
    """Ensure every grok.Form has a grok.require directive"""
    martian.component(grok.Form)


class CheckRequireGrokkerAddForm(CheckRequireGrokker):
    """Ensure every grok.AddForm has a grok.require directive"""
    martian.component(grok.AddForm)


class CheckRequireGrokkerEditForm(CheckRequireGrokker):
    """Ensure every grok.EditForm has a grok.require directive"""
    martian.component(grok.EditForm)



import os.path

from setuptools import setup


version = '5.0'


detailed = open(
    os.path.join('src', 'megrok', 'strictrequire', 'README.rst')).read()


changes = open('CHANGES.rst').read()


long_description = '\n\n'.join([detailed, changes, ''])


tests_require = [
    'zope.component',
    'zope.interface',
    'zope.securitypolicy',
    'zope.testing',
    'zope.testrunner >= 6.4',
]


setup(
    name='megrok.strictrequire',
    version=version,
    description=(
        'Checks that all grokked "view-like" components '
        'require a permission.'),
    long_description=long_description,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved :: Zope Public License",
        "Natural Language :: English",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
    ],
    keywords=[],
    author='The Health Agency',
    author_email='techniek@thehealthagency.com',
    url='http://www.thehealthagency.com',
    license='ZPL 2.1',
    package_dir={'': 'src'},
    packages=['megrok.strictrequire'],
    include_package_data=True,
    zip_safe=False,
    python_requires='>=3.7',
    install_requires=[
        'setuptools',
        'martian',
        'grok >= 5.0a1',
    ],
    extras_require={
        'test': tests_require
    },
    tests_require=tests_require,
    entry_points={},
)



#############################################################################
#
# Copyright (c) 2010 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import doctest
import unittest

import zope.component.testlayer

import megrok.strictrequire.tests


layer = zope.component.testlayer.ZCMLFileLayer(megrok.strictrequire.tests)


def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(
        doctest.DocFileSuite(
            'checkrequire.rst',
            optionflags=(
                doctest.NORMALIZE_WHITESPACE +
                doctest.ELLIPSIS)))
    suite.layer = layer
    return suite
